! AdHints file


Object First_Things "h" Hints
  has general
  class HintClass
  with short_name "Where'd the printer go?",
       the_hints "The shadowy figure could only go down..."
		 "Have you thoroughly searched the first floor?"
		 "There's an interesting door there..."
		 "Enter the janitor's closet and LISTEN.",
       hint_check
       [; if (closet has visited) give self solved; ];

Object Next_Thing "h" Hints
  has general
  class HintClass
  with short_name "What do I do next?",
       the_hints "The owner of the grumbling voice in the janitor's closet \
                  has the stolen printer, but the entrance to his location \
                  isn't on the first floor..."
                 "Try wandering around on the second floor."
                 "See the next section of hints for more info on what to do \
                  on the second floor.",
       hint_check
       [; if (floor2mid has visited) give self solved; ];

Object Red_Herring_Puzzle "h" Hints
  has general
  class HintClass
  with short_name "What do I do in the lab?",
       the_hints "Have you noticed the black box?"
		 "Have you tried pushing the buttons on the black box?"
		 "Don't reveal any more hints unless you've found the wrench."
		 "The wrench is under the lab tables."
		 "OPEN AQUARIUM WITH WRENCH"
		 "GET FISH"
		 "X FISH"
		 "It's a red herring."
		 "So is the hint about the wrench.",
       hint_check
       [; if (lab has visited) give self solved; ];

Object Maze_Entry "h" Hints
  has general
  class HintClass
  with short_name "The halls of learning",
       the_hints "Something's different on the second floor..."
	         "Check out strange noises..."
		 "It wasn't the humming doorknob!"
		 "(If you haven't tried the doorknob, check it out... \
		  but be sure to save first!)"
		 "Isn't the description of the water fountain on the second \
		  floor a little different?"
	         "MOVE THE FOUNTAIN."
	         "OPEN THE PANEL"
	         "GO DOWN (twice)"
	         "Kind of dark down there, isn't it?"
	         "See the next section of hints for more info on what to do \
	          about the darkness.",
       hint_check
       [; if (panel has open) give self solved; ];

Object Flashlight_Puzzle "h" Hints
  has general
  class HintClass
  with short_name "The light and the dark.",
       the_hints "Search the third floor..."
		 "See that box?"
                 "SEARCH the red box."
                 "GET the flashlight (our UK friends may call it a TORCH)."
                 "As a convenience, you may activate or deactivate the \
                  flashlight by typing just ON or OFF.",
       hint_check
       [; if (flashlight in player) give self solved; ];

Object Mouse_Puzzle "h" Hints
  has general
  class HintClass
  with short_name "Of mice and men",
       the_hints "Stuck in the maze?  Help comes to those who wait..."
		 "The mouse really *does* seem to know where it's going..."
		 "Don't get violent!  You might scare the poor little thing \
		  away forever!"
		 "Just FOLLOW the mouse and your path is easy.",
       hint_check
       [; if (lair has visited) give self solved; ];

Object Reverse_Maze_Puzzle "h" Hints
  has general
  class HintClass
  with short_name "Reversing direction",
       the_hints "The mouse only leads you one way, TOWARD the gnome's lair."
                 "But the gnome is forgetful..."
                 "The gnome has posted the directions out of the maze by the \
                  exit."
                 "The directions out of the maze are:^W - W - W - E - E - W - U",
       hint_check
       [; if (lair has visited) give self solved; ];

Object Now_What "h" Hints
  has general
  class HintClass
  with short_name "Now what?",
       the_hints "The gnome needs a copy of the Inform Designer's Manual."
                 "You have a way of getting him one."
                 "Go back to the Computer Center and follow the directions \
                  in the next set of hints.",
       hint_check
       [; if (lpr has general) give self solved; ];

Object Manual_Puzzle "h" Hints
  has general
  class HintClass
  with short_name "Manual labor",
       the_hints "Have you checked out the computer on your desk?"
		 "Look at all those icons.  I wonder what the (computer) \
		mouse can do with them?"
		 "First you have to get the ftp client running..."
		 "Then you need to pick the ftp site to open..."
		 "Then you need to download the file..."
		 "Then you need to print it off.  Voila!"
		 "Okay, here's the exact sequence:"
		 "CLICK ON FTP"
		 "CLICK ON IF ARCHIVE"
		 "CLICK ON DESIGNERS_MANUAL"
		 "CLICK ON LPR",
       hint_check
       [; if (inform_manual in player) give self solved; ];
